@@ -1,18 +1,21 @@
 /*
     Copyright 2012, 2013  Daniel Vrátil <dvratil@redhat.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
+    This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    GNU Lesser General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "authwidget_p.h"
@@ -22,20 +25,16 @@
 #include "private/newtokensfetchjob_p.h"
 #include "../../debug.h"
 
-#include <QWebView>
-#include <QWebFrame>
-#include <QWebElement>
+#include <QWebEngineView>
 #include <QNetworkReply>
+#include <QContextMenuEvent>
 
 #include <QDateTime>
 
-#include <KIO/AccessManager>
-
-
 using namespace KGAPI2;
 
 WebView::WebView(QWidget *parent)
-    : QWebView(parent)
+    : QWebEngineView(parent)
 {
 }
 
@@ -45,12 +44,13 @@ WebView::~WebView()
 
 }
 
-void WebView::contextMenuEvent(QContextMenuEvent *)
+void WebView::contextMenuEvent(QContextMenuEvent *e)
 {
-    //Not menu
+    // No menu
+    e->accept();
 }
 
-AuthWidget::Private::Private(AuthWidget *parent):
+AuthWidgetPrivate::AuthWidgetPrivate(AuthWidget *parent):
     QObject(),
     showProgressBar(true),
     progress(AuthWidget::None),
@@ -59,11 +59,11 @@ AuthWidget::Private::Private(AuthWidget *parent):
     setupUi();
 }
 
-AuthWidget::Private::~Private()
+AuthWidgetPrivate::~AuthWidgetPrivate()
 {
 }
 
-void AuthWidget::Private::setupUi()
+void AuthWidgetPrivate::setupUi()
 {
     vbox = new QVBoxLayout(q);
     q->setLayout(vbox);
@@ -82,28 +82,14 @@ void AuthWidget::Private::setupUi()
     vbox->addWidget(progressbar);
 
     webview = new WebView(q);
-    KIO::AccessManager *m = new KIO::AccessManager(webview);
-    webview->page()->networkAccessManager()->setProxyFactory(m->proxyFactory());
-    connect(webview->page()->networkAccessManager(), &QNetworkAccessManager::sslErrors,
-            this, &Private::onSslError);
-
 
     vbox->addWidget(webview);
-    connect(webview, &QWebView::loadProgress, progressbar, &QProgressBar::setValue);
-    connect(webview, &QWebView::urlChanged, this, &Private::webviewUrlChanged);
-    connect(webview, &QWebView::loadFinished, this, &Private::webviewFinished);
+    connect(webview, &QWebEngineView::loadProgress, progressbar, &QProgressBar::setValue);
+    connect(webview, &QWebEngineView::urlChanged, this, &AuthWidgetPrivate::webviewUrlChanged);
+    connect(webview, &QWebEngineView::loadFinished, this, &AuthWidgetPrivate::webviewFinished);
 }
 
-void AuthWidget::Private::onSslError(QNetworkReply *reply, const QList<QSslError> &errors)
-{
-    Q_FOREACH (const QSslError &error, errors) {
-        qCDebug(KGAPIDebug) << "SSL ERROR: " << error.errorString();
-    }
-    reply->ignoreSslErrors();
-}
-
-
-void AuthWidget::Private::setProgress(AuthWidget::Progress progress)
+void AuthWidgetPrivate::setProgress(AuthWidget::Progress progress)
 {
     qCDebug(KGAPIDebug) << progress;
     this->progress = progress;
@@ -111,7 +97,7 @@ void AuthWidget::Private::setProgress(AuthWidget::Progress progress)
 }
 
 
-void AuthWidget::Private::emitError(const enum Error errCode, const QString& msg)
+void AuthWidgetPrivate::emitError(const enum Error errCode, const QString& msg)
 {
     label->setVisible(true);
     webview->setVisible(false);
@@ -124,7 +110,7 @@ void AuthWidget::Private::emitError(const enum Error errCode, const QString& msg
 }
 
 
-void AuthWidget::Private::webviewUrlChanged(const QUrl &url)
+void AuthWidgetPrivate::webviewUrlChanged(const QUrl &url)
 {
     qCDebug(KGAPIDebug) << url;
 
@@ -139,7 +125,7 @@ void AuthWidget::Private::webviewUrlChanged(const QUrl &url)
     }
 }
 
-void AuthWidget::Private::webviewFinished(bool ok)
+void AuthWidgetPrivate::webviewFinished(bool ok)
 {
     if (!ok) {
         qCWarning(KGAPIDebug) << "Failed to load" << webview->url();
@@ -153,20 +139,16 @@ void AuthWidget::Private::webviewFinished(bool ok)
             return;
         }
 
-        QWebFrame *frame = webview->page()->mainFrame();
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+        const auto js = QStringLiteral("document.getElementById(\"%1\").value = \"%2\";");
         if (!username.isEmpty()) {
-            QWebElement email = frame->findFirstElement(QStringLiteral("input#Email"));
-            if (!email.isNull()) {
-                email.setAttribute(QStringLiteral("value"), username);
-            }
+            webview->page()->runJavaScript(js.arg(QStringLiteral("Email"), username));
         }
 
         if (!password.isEmpty()) {
-            QWebElement passd = frame->findFirstElement(QStringLiteral("input#Passwd"));
-            if (!passd.isNull()) {
-                passd.setAttribute(QStringLiteral("value"), password);
-            }
+            webview->page()->runJavaScript(js.arg(QStringLiteral("Passwd"), password));
         }
+#endif
 
         return;
     }
@@ -180,26 +162,30 @@ void AuthWidget::Private::webviewFinished(bool ok)
             /* Skip the 'code=' string as well */
             token = title.mid (pos + 5);
         } else {
-            qCDebug(KGAPIDebug) << "Parsing token page failed. Title:" << title;
-            qCDebug(KGAPIRaw) << webview->page()->mainFrame()->toHtml();
+            webview->page()->toHtml([title](const QString &html) {
+                qCDebug(KGAPIDebug) << "Parsing token page failed. Title:" << title;
+                qCDebug(KGAPIDebug) << html;
+            });
             emitError(AuthError, tr("Parsing token page failed."));
             return;
         }
 
         if (token.isEmpty()) {
-            qCDebug(KGAPIDebug) << "Failed to obtain token.";
-            qCDebug(KGAPIRaw) << webview->page()->mainFrame()->toHtml();
+            webview->page()->toHtml([](const QString &html) {
+                qCDebug(KGAPIDebug) << "Failed to obtain token.";
+                qCDebug(KGAPIRaw) << html;
+            });
             emitError(AuthError, tr("Failed to obtain token."));
             return;
         }
 
         KGAPI2::NewTokensFetchJob *fetchJob = new KGAPI2::NewTokensFetchJob(token, apiKey, secretKey);
         connect(fetchJob, &Job::finished,
-                this, &Private::tokensReceived);
+                this, &AuthWidgetPrivate::tokensReceived);
     }
 }
 
-void AuthWidget::Private::tokensReceived(KGAPI2::Job* job)
+void AuthWidgetPrivate::tokensReceived(KGAPI2::Job* job)
 {
     KGAPI2::NewTokensFetchJob *tokensFetchJob = qobject_cast<KGAPI2::NewTokensFetchJob*>(job);
 
@@ -211,11 +197,11 @@ void AuthWidget::Private::tokensReceived(KGAPI2::Job* job)
     KGAPI2::AccountInfoFetchJob *fetchJob = new KGAPI2::AccountInfoFetchJob(account, this);
 
     connect(fetchJob, &Job::finished,
-            this, &Private::accountInfoReceived);
+            this, &AuthWidgetPrivate::accountInfoReceived);
     qCDebug(KGAPIDebug) << "Requesting AccountInfo";
 }
 
-void AuthWidget::Private::accountInfoReceived(KGAPI2::Job* job)
+void AuthWidgetPrivate::accountInfoReceived(KGAPI2::Job* job)
 {
     if (job->error()) {
         qCDebug(KGAPIDebug) << "Error when retrieving AccountInfo:" << job->errorString();
