@@ -1,18 +1,34 @@
 /*
-    SPDX-FileCopyrightText: 2012 Jan Grulich <grulja@gmail.com>
+    Copyright (C) 2012  Jan Grulich <grulja@gmail.com>
 
-    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#pragma once
 
-#include "kgapilatitude_export.h"
+#ifndef LIBKGAPI2_OBJECTS_LOCATION_H
+#define LIBKGAPI2_OBJECTS_LOCATION_H
+
 #include "object.h"
 #include "types.h"
+#include "kgapilatitude_export.h"
 
 #include <KContacts/Geo>
 
-#include <QSharedPointer>
+#include <QtCore/QSharedPointer>
 
 namespace KGAPI2
 {
@@ -24,9 +40,11 @@ namespace KGAPI2
  * @author Jan Grulich <grulja@gmail.com>
  * @since 0.4
  */
-class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object, public KContacts::Geo
+class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
+                                      public KContacts::Geo
 {
-public:
+  public:
+
     /**
      * @brief Constructor
      */
@@ -48,7 +66,7 @@ public:
     /**
      * @brief Destructor
      */
-    ~Location() override;
+    virtual ~Location();
 
     /**
      * @brief Timestamp of when this location has been recorded.
@@ -60,7 +78,7 @@ public:
     /**
      * @brief Sets timestamp of this location.
      */
-    void setTimestamp(qulonglong timestamp);
+    void setTimestamp(const qulonglong &timestamp);
 
     /**
      * @brief Returns accuracy of the latitude and longitude in meters.
@@ -72,7 +90,7 @@ public:
     /**
      * @brief Sets accuracy of this location.
      */
-    void setAccuracy(qint32 accuracy);
+    void setAccuracy(const qint32 &accuracy);
 
     /**
      * @brief Returns ground speed of the user at the time this location was
@@ -85,7 +103,7 @@ public:
     /**
      * @brief Sets speed of this location.
      */
-    void setSpeed(qint32 speed);
+    void setSpeed(const qint32 &speed);
 
     /**
      * @brief Returns direction of travel of the user when this location was
@@ -98,7 +116,7 @@ public:
     /**
      * @brief Sets heading of this location.
      */
-    void setHeading(qint32 heading);
+    void setHeading(const qint32 &heading);
 
     /**
      * @brief Returns altitude of this location.
@@ -110,7 +128,7 @@ public:
     /**
      * @brief Sets altitude of this location.
      */
-    void setAltitude(qint32 altitude);
+    void setAltitude(const qint32 &altitude);
 
     /**
      * @brief Returns altitude accuracy.
@@ -122,12 +140,15 @@ public:
     /**
      * @brief Sets altitude accuracy of this location.
      */
-    void setAltitudeAccuracy(qint32 altitudeAccuracy);
+    void setAltitudeAccuracy(const qint32 &altitudeAccuracy);
 
-private:
+  private:
     class Private;
-    Private *const d;
+    Private * const d;
     friend class Private;
+
 };
 
 } // namespace KGAPI2
+
+#endif // LOCATION_H
