@@ -1,19 +1,33 @@
 /*
  * This file is part of LibKGAPI library
  *
- * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
+ * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#pragma once
+#ifndef LIBKGAPI2_LOCATIONFETCHHISTORYJOB_H
+#define LIBKGAPI2_LOCATIONFETCHHISTORYJOB_H
 
 #include "fetchjob.h"
-#include "kgapilatitude_export.h"
 #include "latitude.h"
+#include "kgapilatitude_export.h"
 
-namespace KGAPI2
-{
+namespace KGAPI2 {
 
 /**
  * @brief A job to fetch all past locations from user's account on Google Latitude
@@ -21,7 +35,7 @@ namespace KGAPI2
  * @author Daniel Vrátil <dvratil@redhat.com>
  * @since 2.0
  */
-class KGAPILATITUDE_DEPRECATED_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
+class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
 {
     Q_OBJECT
 
@@ -71,7 +85,8 @@ class KGAPILATITUDE_DEPRECATED_EXPORT LocationFetchHistoryJob : public KGAPI2::F
      */
     Q_PROPERTY(qlonglong maxTimestamp READ maxTimestamp WRITE setMaxTimestamp)
 
-public:
+  public:
+
     /**
      * @brief Constructs a job that will fetch all past user's locations from
      *        Google Latitude service
@@ -79,12 +94,12 @@ public:
      * @param account Account to authenticate the requests
      * @param parent
      */
-    explicit LocationFetchHistoryJob(const AccountPtr &account, QObject *parent = nullptr);
+    explicit LocationFetchHistoryJob(const AccountPtr &account, QObject* parent = nullptr);
 
     /**
      * @brief Destructor
      */
-    ~LocationFetchHistoryJob() override;
+    virtual ~LocationFetchHistoryJob();
 
     /**
      * @brief Returns granularity of the requested locations.
@@ -134,11 +149,12 @@ public:
      */
     void setMaxTimestamp(qlonglong maxTimestamp);
 
-protected:
+  protected:
+
     /**
      * @brief KGAPI2::Job::start implementation
      */
-    void start() override;
+    void start() Q_DECL_OVERRIDE;
 
     /**
      * @brief KGAPI2::Job::handleReplyWithItems
@@ -146,12 +162,16 @@ protected:
      * @param reply
      * @param rawData
      */
-    ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
+    ObjectsList handleReplyWithItems(const QNetworkReply *reply,
+                                             const QByteArray& rawData) Q_DECL_OVERRIDE;
 
-private:
+  private:
     class Private;
-    Private *const d;
+    Private * const d;
     friend class Private;
+
 };
 
 } // namespace KGAPI2
+
+#endif // LIBKGAPI2_LOCATIONFETCHHISTORYJOB_H
