@@ -1,7 +1,21 @@
 /*
-    SPDX-FileCopyrightText: 2012 Jan Grulich <grulja@gmail.com>
+    Copyright (C) 2012  Jan Grulich <grulja@gmail.com>
 
-    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "staticmapmarker.h"
@@ -16,10 +30,10 @@ public:
 
     void init(const Private &other);
 
-    LocationType locationType = StaticMapMarker::Undefined;
-    MarkerSize size = StaticMapMarker::Normal;
+    LocationType locationType;
+    MarkerSize size;
 
-    QColor color = Qt::red;
+    QColor color;
     QChar label;
 
     QStringList locationsString;
@@ -27,11 +41,13 @@ public:
     QList<KContacts::Geo> locationsGeo;
 };
 
-StaticMapMarker::Private::Private()
-{
-}
+StaticMapMarker::Private::Private():
+    locationType(StaticMapMarker::Undefined),
+    size(StaticMapMarker::Normal),
+    color(Qt::red)
+{ }
 
-StaticMapMarker::Private::Private(const Private &other)
+StaticMapMarker::Private::Private(const Private & other)
 {
     init(other);
 }
@@ -47,13 +63,13 @@ void StaticMapMarker::Private::init(const Private &other)
     locationsGeo = other.locationsGeo;
 }
 
-StaticMapMarker::StaticMapMarker()
-    : d(new Private)
+StaticMapMarker::StaticMapMarker():
+    d(new Private)
 {
 }
 
-StaticMapMarker::StaticMapMarker(const QString &address, const QChar &label, const MarkerSize size, const QColor &color)
-    : d(new Private)
+StaticMapMarker::StaticMapMarker (const QString& address, const QChar& label, const MarkerSize size, const QColor& color):
+    d(new Private)
 {
     QStringList list;
     list << address;
@@ -64,8 +80,8 @@ StaticMapMarker::StaticMapMarker(const QString &address, const QChar &label, con
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const KContacts::Address &address, QChar label, const MarkerSize size, const QColor &color)
-    : d(new Private)
+StaticMapMarker::StaticMapMarker (const KContacts::Address& address, const QChar& label, const MarkerSize size, const QColor& color):
+    d(new Private)
 {
     KContacts::Address::List list;
     list << address;
@@ -76,8 +92,8 @@ StaticMapMarker::StaticMapMarker(const KContacts::Address &address, QChar label,
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const KContacts::Geo &address, QChar label, const MarkerSize size, const QColor &color)
-    : d(new Private)
+StaticMapMarker::StaticMapMarker (const KContacts::Geo& address, const QChar& label, const MarkerSize size, const QColor& color):
+    d(new Private)
 {
     QList<KContacts::Geo> list;
     list << address;
@@ -88,8 +104,9 @@ StaticMapMarker::StaticMapMarker(const KContacts::Geo &address, QChar label, con
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const QStringList &locations, QChar label, const MarkerSize size, const QColor &color)
-    : d(new Private)
+StaticMapMarker::StaticMapMarker(const QStringList & locations, const QChar& label,
+                                 const MarkerSize size, const QColor& color):
+    d(new Private)
 {
     d->locationType = String;
     d->locationsString = locations;
@@ -98,8 +115,9 @@ StaticMapMarker::StaticMapMarker(const QStringList &locations, QChar label, cons
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const KContacts::Address::List &locations, QChar label, const MarkerSize size, const QColor &color)
-    : d(new Private)
+StaticMapMarker::StaticMapMarker(const KContacts::Address::List & locations, const QChar& label,
+                                 const MarkerSize size, const QColor& color):
+    d(new Private)
 {
     d->locationType = KABCAddress;
     d->locationsAddress = locations;
@@ -108,8 +126,9 @@ StaticMapMarker::StaticMapMarker(const KContacts::Address::List &locations, QCha
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const QList<KContacts::Geo> &locations, QChar label, const MarkerSize size, const QColor &color)
-    : d(new Private)
+StaticMapMarker::StaticMapMarker(const QList< KContacts::Geo >& locations, const QChar& label,
+                                 const MarkerSize size, const QColor& color):
+    d(new Private)
 {
     d->locationType = KABCGeo;
     d->locationsGeo = locations;
@@ -118,8 +137,8 @@ StaticMapMarker::StaticMapMarker(const QList<KContacts::Geo> &locations, QChar l
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const StaticMapMarker &other)
-    : d(new Private(*(other.d)))
+StaticMapMarker::StaticMapMarker(const StaticMapMarker& other):
+    d(new Private(*(other.d)))
 {
 }
 
@@ -138,7 +157,7 @@ QColor StaticMapMarker::color() const
     return d->color;
 }
 
-void StaticMapMarker::setColor(const QColor &color)
+void StaticMapMarker::setColor(const QColor& color)
 {
     d->color = color;
 }
@@ -153,7 +172,7 @@ QChar StaticMapMarker::label() const
     return d->label;
 }
 
-void StaticMapMarker::setLabel(QChar label)
+void StaticMapMarker::setLabel(const QChar& label)
 {
     d->label = label;
 }
@@ -163,7 +182,7 @@ QStringList StaticMapMarker::locationsString() const
     return d->locationsString;
 }
 
-void StaticMapMarker::setLocation(const QString &location)
+void StaticMapMarker::setLocation(const QString& location)
 {
     d->locationType = String;
     d->locationsString.clear();
@@ -172,7 +191,7 @@ void StaticMapMarker::setLocation(const QString &location)
     d->locationsGeo.clear();
 }
 
-void StaticMapMarker::setLocations(const QStringList &locations)
+void StaticMapMarker::setLocations(const QStringList& locations)
 {
     d->locationType = KABCAddress;
     d->locationsString = locations;
@@ -185,7 +204,7 @@ KContacts::Address::List StaticMapMarker::locationsAddress() const
     return d->locationsAddress;
 }
 
-void StaticMapMarker::setLocation(const KContacts::Address &location)
+void StaticMapMarker::setLocation(const KContacts::Address& location)
 {
     d->locationType = KABCAddress;
     d->locationsAddress.clear();
@@ -202,12 +221,12 @@ void StaticMapMarker::setLocations(const KContacts::Address::List &locations)
     d->locationsGeo.clear();
 }
 
-QList<KContacts::Geo> StaticMapMarker::locationsGeo() const
+QList< KContacts::Geo > StaticMapMarker::locationsGeo() const
 {
     return d->locationsGeo;
 }
 
-void StaticMapMarker::setLocation(const KContacts::Geo &location)
+void StaticMapMarker::setLocation(const KContacts::Geo& location)
 {
     d->locationType = KABCGeo;
     d->locationsGeo.clear();
@@ -216,7 +235,7 @@ void StaticMapMarker::setLocation(const KContacts::Geo &location)
     d->locationsAddress.clear();
 }
 
-void StaticMapMarker::setLocations(const QList<KContacts::Geo> &locations)
+void StaticMapMarker::setLocations(const QList< KContacts::Geo >& locations)
 {
     d->locationType = KABCGeo;
     d->locationsGeo = locations;
@@ -252,40 +271,44 @@ QString StaticMapMarker::toString() const
         break;
     }
 
-    if (d->color != Qt::red) {
-        ret += QLatin1String("color:") + d->color.name().replace(QLatin1Char('#'), QLatin1String("0x")) + QLatin1Char('|');
-    }
+    if (d->color != Qt::red)
+        ret += QLatin1String("color:") + d->color.name().replace(QLatin1Char('#'), QLatin1String("0x")) + QLatin1String("|");
 
-    if (d->label.isLetterOrNumber() && d->size > 1) {
-        ret += QLatin1String("label:") + d->label.toUpper() + QLatin1Char('|');
-    }
+    if (d->label.isLetterOrNumber() && d->size > 1)
+        ret += QLatin1String("label:") + d->label.toUpper() + QLatin1String("|");
 
     if (d->locationType == String) {
-        for (const QString &addr : std::as_const(d->locationsString)) {
-            ret += addr + QLatin1Char('|');
+
+        Q_FOREACH(const QString & addr, d->locationsString) {
+            ret += addr + QLatin1String("|");
         }
 
     } else if (d->locationType == KABCAddress) {
-        for (const KContacts::Address &addr : std::as_const(d->locationsAddress)) {
-            ret += addr.formatted(KContacts::AddressFormatStyle::Postal) + QLatin1Char('|');
+
+        Q_FOREACH(const KContacts::Address & addr, d->locationsAddress) {
+            ret += addr.formattedAddress() + QLatin1String("|");
         }
 
     } else if (d->locationType == KABCGeo) {
-        for (const KContacts::Geo &addr : std::as_const(d->locationsGeo)) {
-            ret += QString::number(addr.latitude()) + QLatin1Char(',') + QString::number(addr.longitude()) + QLatin1Char('|');
+
+        Q_FOREACH(const KContacts::Geo & addr, d->locationsGeo) {
+            ret += QString::number(addr.latitude()) + QLatin1String(",") +
+                  QString::number(addr.longitude()) + QLatin1String("|");
         }
+
     }
 
-    ret.replace(QLatin1String(", "), QLatin1String(","));
-    ret.replace(QLatin1String(". "), QLatin1String("."));
-    ret.replace(QLatin1Char(' '), QLatin1Char('+'));
-    ret.replace(QLatin1Char('\n'), QLatin1Char(','));
-    ret.remove(ret.lastIndexOf(QLatin1Char('|')), 1);
+    ret = ret.replace(QLatin1String(", "), QLatin1String(","));
+    ret = ret.replace(QLatin1String(". "), QLatin1String("."));
+    ret = ret.replace(QLatin1Char(' '), QLatin1Char('+'));
+    ret = ret.replace(QLatin1Char('\n'), QLatin1Char(','));
+    ret = ret.remove(ret.lastIndexOf(QLatin1Char('|')), 1);
 
     return ret;
+
 }
 
-StaticMapMarker &StaticMapMarker::operator=(const StaticMapMarker &other)
+StaticMapMarker& StaticMapMarker::operator=(const StaticMapMarker& other)
 {
     if (&other == this) {
         return *this;
